@@ -1,4 +1,4 @@
-package Mojo::Base::Role::PromiseClass 0.007;
+package Mojo::Base::Role::PromiseClass 0.008;
 
 # ABSTRACT: Add promise_class attribute to Mojo class
 
@@ -13,7 +13,7 @@ sub promise_roles {
       grep { !Role::Tiny::does_role($pclass, $_) }
       map  { /^\+(.+)$/ ? "Mojo::Promise::Role::$1" : $_ }
       @_;
-    $self->promise_class($pclass->with_roles(@roles)) if @roles || !@_;
+    $self->promise_class($pclass->with_roles(@roles)) if @roles;
     return $self;
 }
 
@@ -31,7 +31,7 @@ Mojo::Base::Role::PromiseClass - Add promise_class attribute to Mojo class
 
 =head1 VERSION
 
-version 0.007
+version 0.008
 
 =head1 SYNOPSIS
 
@@ -104,7 +104,7 @@ Roger Crew <wrog@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2019 by Roger Crew.
+This software is Copyright (c) 2020 by Roger Crew.
 
 This is free software, licensed under:
 
